SystemOrganization addCategory: #ConfigurationOfSightCallgraph!

Object subclass: #ConfigurationOfSightCallgraph
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSightCallgraph'!

!ConfigurationOfSightCallgraph class methodsFor: 'private' stamp: 'mt 1/31/2012 16:15:17.684'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSightCallgraph class methodsFor: 'private' stamp: 'mt 1/31/2012 16:15:17.694'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSightCallgraph class methodsFor: 'metacello tool support' stamp: 'mt 1/31/2012 16:15:17.706'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSightCallgraph class methodsFor: 'metacello tool support' stamp: 'mt 1/31/2012 16:15:17.715'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSightCallgraph class methodsFor: 'loading' stamp: 'mt 1/31/2012 16:15:17.733'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSightCallgraph class methodsFor: 'loading' stamp: 'mt 1/31/2012 16:15:17.741'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSightCallgraph class methodsFor: 'loading' stamp: 'mt 1/31/2012 16:15:17.75'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfSightCallgraph class methodsFor: 'metacello tool support' stamp: 'mt 1/31/2012 16:15:17.724'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSightCallgraph class methodsFor: 'accessing' stamp: 'mt 1/31/2012 16:15:17.759'!
project

	^self new project! !

!ConfigurationOfSightCallgraph class methodsFor: 'unloading Metacello' stamp: 'mt 1/31/2012 16:15:17.767'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSightCallgraph methodsFor: 'baselines' stamp: 'mt 2/1/2012 13:48:49.454'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'. 
					
		spec
			package: 'MethodWrappers' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
								
		spec 
			package: 'Sight-Callgraph' with: [spec
				requires: #( 'MethodWrappers' )].
		
		spec project: 'Sight-Coverage' with: [
			spec
				className: 'ConfigurationOfSightCoverage';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec
			group: 'default' with: #('Sight-Callgraph');
			group: 'coverage' with: #('Sight-Callgraph' 'Sight-Coverage') ].! !

!ConfigurationOfSightCallgraph methodsFor: 'symbolic versions' stamp: 'mt 1/31/2012 16:15:17.631'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.0.1'.! !

!ConfigurationOfSightCallgraph methodsFor: 'accessing' stamp: 'mt 1/31/2012 16:15:17.656'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSightCallgraph methodsFor: 'symbolic versions' stamp: 'mt 1/31/2012 16:15:17.639'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '1.0'.! !

!ConfigurationOfSightCallgraph methodsFor: 'symbolic versions' stamp: 'mt 1/31/2012 16:15:17.648'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.2.x' version: '1.0'.! !

!ConfigurationOfSightCallgraph methodsFor: 'versions' stamp: 'mt 2/1/2012 13:49:03.997'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		
		spec
			package: 'MethodWrappers' with: 'MethodWrappers-mt.20';
			package: 'Sight-Callgraph' with: 'Sight-Callgraph-mt.5';
			project: 'Sight-Coverage' with: '1.0'].! !

!ConfigurationOfSightCallgraph methodsFor: 'versions' stamp: 'mt 1/31/2012 16:18:58.674'!
version101: spec 
	<version: '1.0.1' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
		spec description: 'bugfix version'].! !
